searchNodes=[{"doc":"Querying a Tribes 2 server actually requires sending 2 different packets to the server where the first byte is denoting the type of information we're asking for. The first is called the info packet which doesnt contain much more then the server name. The second is called the status packet which contains all the meat and potatoes. The T2ServerQuery.query/3 function makes requests for both info and status and combines them into a single response for easy consumption. Installation def deps do [ { :t2_server_query , &quot;~&gt; 0.1.0&quot; } ] end Usage # T2ServerQuery.query(&quot;35.239.88.241&quot;, port // 28_000, timeout // 3_500) T2ServerQuery . query ( &quot;35.239.88.241&quot; )","ref":"T2ServerQuery.html","title":"T2ServerQuery","type":"module"},{"doc":"Perform a server query. Results should be in the form of a tuple with either :ok or :error { :ok , % T2ServerQuery.QueryResult { ... } } { :error , % T2ServerQuery.QueryResult { ... } } Examples iex&gt; T2ServerQuery . query ( &quot;35.239.88.241&quot; ) { :ok , % T2ServerQuery.QueryResult { bot_count : 0 , game_type : &quot;Classic&quot; , map_name : &quot;Canker&quot; , max_player_count : 64 , mission_type : &quot;LakRabbit&quot; , player_count : 0 , players : [ %{ } ] , server_description : &quot;Celebrating 20 Years of Tribes2! More information in Discord. &lt;a:playt2.com/discord&gt;playt2.com/discord&lt;/a&gt;&quot; , server_name : &quot;Discord PUB&quot; , server_status : :online , team_count : 1 , teams : [ %{ name : &quot;Storm&quot; , score : 0 } ] } } iex&gt; T2ServerQuery . query ( &quot;127.0.0.1&quot; ) { :error , % T2ServerQuery.QueryResult { bot_count : 0 , game_type : &quot;&quot; , map_name : &quot;&quot; , max_player_count : 0 , mission_type : &quot;&quot; , player_count : 0 , players : [ ] , server_description : &quot;Host unreachable, timed out.&quot; , server_name : &quot;127.0.0.1:28000&quot; , server_status : :offline , team_count : 0 , teams : [ ] } }","ref":"T2ServerQuery.html#query/3","title":"T2ServerQuery.query/3","type":"function"},{"doc":"This module does the heavy lifting with parsing a Tribes 2 query response packet. UDP Packet Anatomy Info Packet &lt;&lt; _header :: size ( 192 ) , server_name :: bitstring &gt;&gt; Status Packet &lt;&lt; _header :: size ( 48 ) , game_type_length :: little - integer , game_type :: binary - size ( game_type_length ) , mission_type_length :: little - integer , mission_type :: binary - size ( mission_type_length ) , map_name_length :: little - integer , map_name :: binary - size ( map_name_length ) , _skip_a :: size ( 8 ) , player_count :: little - integer , max_player_count :: little - integer , bot_count :: little - integer , _skip_b :: size ( 16 ) , server_description_length :: little - integer , server_description :: binary - size ( server_description_length ) , _skip_c :: size ( 16 ) , team_count :: binary - size ( 1 ) , rest :: bitstring &gt;&gt; Notice the _skip_(a|b|c) mappings. I havn't quite figured out what they refer to yet but they don't seem that important. They likely relate to a few server flags like tournament_mode , cpu_speed , is_linux . Refer to T2ServerQuery.QueryResult for what a typical struct would look like.","ref":"T2ServerQuery.PacketParser.html","title":"T2ServerQuery.PacketParser","type":"module"},{"doc":"This function expects both an info and status packet to be passed in that is in a Base.encode16 format. Normally you wouldn't need to run this function manually since it's called in a pipeline from the main T2ServerQuery.query","ref":"T2ServerQuery.PacketParser.html#init/2","title":"T2ServerQuery.PacketParser.init/2","type":"function"},{"doc":"Struct Shape % T2ServerQuery.QueryResult { server_status : :online , bot_count : 30 , game_type : &quot;Classic&quot; , map_name : &quot;Cold as Ice [b]&quot; , max_player_count : 64 , mission_type : &quot;Capture the Flag&quot; , player_count : 29 , players : [ %{ player : &quot;Rooster128&quot; , score : &quot;0&quot; , team : &quot;Storm&quot; } , %{ player : &quot;sneakygnome&quot; , score : &quot;0&quot; , team : &quot;Inferno&quot; } , %{ player : &quot;Waldred &quot; , score : &quot;0&quot; , team : &quot;Inferno&quot; } , %{ player : &quot;HDPTetchy &quot; , score : &quot;0&quot; , team : &quot;Storm&quot; } , %{ player : &quot;0wnj0o&quot; , score : &quot;0&quot; , team : &quot;Inferno&quot; } , %{ player : &quot;idjit &quot; , score : &quot;0&quot; , team : &quot;Storm&quot; } , %{ player : &quot;JesusChrist &quot; , score : &quot;0&quot; , team : &quot;Storm&quot; } , %{ player : &quot;Sofaking--bakeD &quot; , score : &quot;0&quot; , team : &quot;Inferno&quot; } , %{ player : &quot;saKe &quot; , score : &quot;0&quot; , team : &quot;Inferno&quot; } , %{ player : &quot;ZurkinWood497&quot; , score : &quot;0&quot; , team : &quot;Storm&quot; } , %{ player : &quot;TerryTC &quot; , score : &quot;0&quot; , team : &quot;Inferno&quot; } , %{ player : &quot;WankBullet &quot; , score : &quot;0&quot; , team : &quot;Storm&quot; } , %{ player : &quot;CyClones&quot; , score : &quot;0&quot; , team : &quot;Inferno&quot; } , %{ player : &quot;huntergirl10&quot; , score : &quot;0&quot; , team : &quot;Storm&quot; } , %{ player : &quot;ChocoTaco&quot; , score : &quot;0&quot; , team : &quot;Inferno&quot; } , %{ player : &quot;Dirk&quot; , score : &quot;0&quot; , team : &quot;Storm&quot; } , %{ player : &quot;Krell&quot; , score : &quot;0&quot; , team : &quot;Storm&quot; } , %{ player : &quot;high5slayer&quot; , score : &quot;0&quot; , team : &quot;Inferno&quot; } , %{ player : &quot;Red Fraction &quot; , score : &quot;0&quot; , team : &quot;Inferno&quot; } , %{ player : &quot;-MaLice--&quot; , score : &quot;0&quot; , team : &quot;Storm&quot; } , %{ player : &quot;wiltedflower &quot; , score : &quot;0&quot; , team : &quot;Inferno&quot; } , %{ player : &quot;Glarm &quot; , score : &quot;0&quot; , team : &quot;Storm&quot; } , %{ player : &quot;AlphaSentinel&quot; , score : &quot;0&quot; , team : &quot;Inferno&quot; } , %{ player : &quot;The-Punisher &quot; , score : &quot;0&quot; , team : &quot;Storm&quot; } , %{ player : &quot;2SmOkeD&quot; , score : &quot;0&quot; , team : &quot;Inferno&quot; } , %{ player : &quot;iPrecision&quot; , score : &quot;0&quot; , team : &quot;Storm&quot; } , %{ player : &quot;Halo 2 &quot; , score : &quot;0&quot; , team : &quot;Storm&quot; } , %{ player : &quot;Sami-FIN &quot; , score : &quot;0&quot; , team : &quot;Inferno&quot; } , %{ player : &quot;rileygarbels&quot; , score : &quot;0&quot; , team : &quot;Storm&quot; } ] , server_description : &quot;This server is using bots that are adapted to playing Classic. http://tribes2bots.byethost4.com/forum/index.php?topic=57.msg234&quot; , server_name : &quot;Classic Bots Server&quot; , team_count : 2 , teams : [ %{ name : &quot;Storm&quot; , score : &quot;0&quot; } , %{ name : &quot;Inferno&quot; , score : &quot;0&quot; } ] }","ref":"T2ServerQuery.QueryResult.html","title":"T2ServerQuery.QueryResult","type":"module"},{"doc":"T2ServerQuery Querying a Tribes 2 server actually requires sending 2 different packets to the server where the first byte is denoting the type of information we're asking for. The first is called the info packet which doesnt contain much more then the server name. The second is called the status packet which contains all the meat and potatoes. The T2ServerQuery.query/3 function makes requests for both info and status and combines them into a single response for easy consumption.","ref":"readme.html","title":"T2ServerQuery","type":"extras"},{"doc":"The package can be installed by adding t2_server_query to your list of dependencies in mix.exs : def deps do [ { :t2_server_query , &quot;~&gt; 0.1.0&quot; } ] end","ref":"readme.html#installation","title":"T2ServerQuery - Installation","type":"extras"},{"doc":"# T2ServerQuery.query(&quot;35.239.88.241&quot;, port // 28_000, timeout // 3_500) T2ServerQuery . query ( &quot;35.239.88.241&quot; ) { :ok , % T2ServerQuery.QueryResult { bot_count : 0 , game_type : &quot;Classic&quot; , map_name : &quot;Canker&quot; , max_player_count : 64 , mission_type : &quot;LakRabbit&quot; , player_count : 0 , players : [ %{ } ] , server_description : &quot;Celebrating 20 Years of Tribes2! More information in Discord. &lt;a:playt2.com/discord&gt;playt2.com/discord&lt;/a&gt;&quot; , server_name : &quot;Discord PUB&quot; , server_status : :online , team_count : 1 , teams : [ %{ name : &quot;Storm&quot; , score : 0 } ] } }","ref":"readme.html#usage","title":"T2ServerQuery - Usage","type":"extras"},{"doc":"The docs can be found at https://hexdocs.pm/t2_server_query . Documentation has been generated with ExDoc and published on HexDocs .","ref":"readme.html#docs","title":"T2ServerQuery - Docs","type":"extras"}]